pub struct TemplateChunkSetRecord {
pub payload_hash: Vec<u8>,
pub payload_size_bytes: u64,
pub chunk_count: u32,
pub chunk_hashes: Vec<Vec<u8>>,
pub created_at: u64,
}Expand description
TemplateChunkSetRecord
Fields
payload_hash: Vec<u8>payload_size_bytes: u64chunk_count: u32chunk_hashes: Vec<Vec<u8>>created_at: u64Trait Implementations
Sourceimpl Clone for TemplateChunkSetRecord
impl Clone for TemplateChunkSetRecord
Sourcefn clone(&self) -> TemplateChunkSetRecord
fn clone(&self) -> TemplateChunkSetRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateChunkSetRecord
impl Debug for TemplateChunkSetRecord
Sourceimpl<'de> Deserialize<'de> for TemplateChunkSetRecord
impl<'de> Deserialize<'de> for TemplateChunkSetRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TemplateChunkSetRecord
impl PartialEq for TemplateChunkSetRecord
Sourceimpl Serialize for TemplateChunkSetRecord
impl Serialize for TemplateChunkSetRecord
Sourceimpl Storable for TemplateChunkSetRecord
impl Storable for TemplateChunkSetRecord
Sourceconst BOUND: Bound = ::canic_memory::cdk::structures::storable::Bound::Unbounded
const BOUND: Bound = ::canic_memory::cdk::structures::storable::Bound::Unbounded
The size bounds of the type.
Sourcefn to_bytes(&self) -> Cow<'_, [u8]>
fn to_bytes(&self) -> Cow<'_, [u8]>
Converts the element into a possibly borrowed byte slice. Read more
Sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
Sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but checks that bytes conform to declared bounds.Sourcefn into_bytes_checked(self) -> Vec<u8> ⓘwhere
Self: Sized,
fn into_bytes_checked(self) -> Vec<u8> ⓘwhere
Self: Sized,
Like
into_bytes, but checks that bytes conform to declared bounds.Sourcefn check_bounds(bytes: &[u8])
fn check_bounds(bytes: &[u8])
Validates that a byte slice fits within this type’s declared bounds.
impl Eq for TemplateChunkSetRecord
impl StructuralPartialEq for TemplateChunkSetRecord